view src/pango-1-fixes.patch @ 2623:7e078ab846b8

update package pango
author Mark Brand <mabrand@mabrand.nl>
date Fri, 15 Jun 2012 16:01:45 +0200
parents 8ffc6695280d
children 059460e131a5
line wrap: on
line source

This file is part of MXE.
See index.html for further information.

Contains ad hoc patches for cross building.

From 2227d3bd55d64510cdb9761a55dfcfa86c594ae4 Mon Sep 17 00:00:00 2001
From: Mark Brand <mabrand@mabrand.nl>
Date: Wed, 29 Sep 2010 00:52:59 +0200
Subject: [PATCH 1/3] s,DllMain,static _disabled_DllMain,

---
 pango/pango-utils.c |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

-- 
1.7.10.4


From f168a8e1bf39a2605850ba2619992b6de99c58ba Mon Sep 17 00:00:00 2001
From: Mark Brand <mabrand@mabrand.nl>
Date: Wed, 29 Sep 2010 00:50:08 +0200
Subject: [PATCH 2/3] add missing lib to pango.pc for static linking

---
 pango.pc.in |    2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/pango.pc.in b/pango.pc.in
index 17a8b7a..16c5981 100644
--- a/pango.pc.in
+++ b/pango.pc.in
@@ -10,5 +10,5 @@ Description: Internationalized text handling
 Version: @VERSION@
 Requires: glib-2.0 gobject-2.0
 Requires.private: gmodule-no-export-2.0
-Libs: -L${libdir} -lpango-@PANGO_API_VERSION@ @PKGCONFIG_MATH_LIBS@
+Libs: -L${libdir} -lpango-@PANGO_API_VERSION@ @PKGCONFIG_MATH_LIBS@ -lusp10
 Cflags: -I${includedir}/pango-1.0
-- 
1.7.10.4


From 6a9d9d2b6151f93a6a0a1a1e3cf8381d47da59a1 Mon Sep 17 00:00:00 2001
From: Mark Brand <mabrand@mabrand.nl>
Date: Fri, 15 Jun 2012 16:21:40 +0200
Subject: [PATCH 3/3] do not force shared for win32

---
 configure.in        |   14 --------------
 modules/Makefile.am |   17 +----------------
 2 files changed, 1 insertion(+), 30 deletions(-)

diff --git a/configure.in b/configure.in
index 8362280..6a000cc 100644
--- a/configure.in
+++ b/configure.in
@@ -147,20 +147,6 @@ CXXFLAGS="$CXXFLAGS -fno-rtti -fno-exceptions"
 # Win32 stuff
 #
 
-AC_LIBTOOL_WIN32_DLL
-AM_DISABLE_STATIC
-
-if test "$pango_os_win32" = "yes"; then
-  if test x$enable_static = xyes -o x$enable_static = x; then
-    AC_MSG_WARN([Disabling static library build, must build as DLL on Windows.])
-    enable_static=no
-  fi
-  if test x$enable_shared = xno; then
-    AC_MSG_WARN([Enabling shared library build, must build as DLL on Windows.])
-  fi
-  enable_shared=yes
-fi
-
 AM_PROG_LIBTOOL
 dnl when using libtool 2.x create libtool early, because it's used in configure
 m4_ifdef([LT_OUTPUT], [LT_OUTPUT])
diff --git a/modules/Makefile.am b/modules/Makefile.am
index dc8a2c8..dc22e59 100644
--- a/modules/Makefile.am
+++ b/modules/Makefile.am
@@ -26,22 +26,7 @@ RUN_QUERY_MODULES_TEST=true
 all-local: pango.modules
 endif
 
-install-data-local: $(top_builddir)/pango/pango-querymodules$(EXEEXT)
-	@if $(RUN_QUERY_MODULES_TEST) && test -z "$(DESTDIR)" ; then 	\
-	  echo $(mkinstalldirs) $(DESTDIR)$(sysconfdir)/pango \&\& 	\
-	  $(top_builddir)/pango/pango-querymodules$(EXEEXT) 		\
-		\> $(DESTDIR)$(sysconfdir)/pango/pango.modules ;	\
-	  $(mkinstalldirs) $(DESTDIR)$(sysconfdir)/pango && 		\
-	  $(top_builddir)/pango/pango-querymodules$(EXEEXT) 		\
-		> $(DESTDIR)$(sysconfdir)/pango/pango.modules ;		\
-	else								\
-	  echo "***" ; 							\
-	  echo "*** Warning: $(sysconfdir)/pango/pango.modules" ; 	\
-	  echo "*** not created" ; 					\
-	  echo "*** Generate this file on the target system" ; 		\
-	  echo "*** using pango-querymodules" ; 			\
-	  echo "***" ; 							\
-	fi
+install-data-local:
 
 uninstall-local:
 	$(RM) $(DESTDIR)$(sysconfdir)/pango/pango.modules
diff --git a/pango/pango-utils.c b/pango/pango-utils.c
index c68e2d4..e55b71d 100644
--- a/pango/pango-utils.c
+++ b/pango/pango-utils.c
@@ -692,12 +692,12 @@ pango_config_key_get (const char *key)
 
 #ifdef G_OS_WIN32
 
 /* DllMain function needed to tuck away the DLL handle */
 
 static HMODULE pango_dll;
 
 BOOL WINAPI
-DllMain (HINSTANCE hinstDLL,
+static _disabled_DllMain (HINSTANCE hinstDLL,
 	 DWORD     fdwReason,
 	 LPVOID    lpvReserved)
 {
@@ -692,12 +692,12 @@ pango_config_key_get (const char *key)
 #ifdef G_OS_WIN32
 
-/* DllMain function needed to tuck away the DLL handle */
+/* static _disabled_DllMain function needed to tuck away the DLL handle */
 
 static HMODULE pango_dll;
-- 
1.7.10.4